import React from 'react';
import PropTypes from 'prop-types';
import Button from '@fenderdigital/react-button';
import Spinner from '@fenderdigital/react-spinner';

class LoadingSpinnerButton extends React.Component {
  constructor() {
    super();
    this.state = { isButtonClicked: false };

    this.handleClick = this.handleClick.bind(this);
  }

  componentDidUpdate(prevProps) {
    const { loading } = this.props;
    if (prevProps.loading && !loading) {
      this.setButtonClicked(false);
    }
  }

  setButtonClicked(isButtonClicked) {
    this.setState({ isButtonClicked });
  }

  handleClick(event) {
    const { onClick } = this.props;

    this.setButtonClicked(true);
    onClick(event);
  }

  render() {
    const {
      children,
      color,
      dataId,
      disabled,
      fontStyles,
      loading,
      requireClick,
      spinnerColor,
      spinnerWidth,
      styles,
      type,
    } = this.props;
    const { isButtonClicked } = this.state;

    const showSpinner = loading && (!requireClick || isButtonClicked);

    return (
      <Button
        dataId={dataId}
        fontStyles={fontStyles}
        styles={styles}
        color={color}
        disabled={disabled || showSpinner}
        onClick={this.handleClick}
        type={type}
      >
        <div className="flex">
          {showSpinner && (
            <div className="pr2">
              <Spinner
                bgColor={color}
                lineColor={spinnerColor}
                strokeBgColor={color}
                width={spinnerWidth}
                strokeWidth={4}
              />
            </div>
          )}
          {children}
        </div>
      </Button>
    );
  }
}

LoadingSpinnerButton.propTypes = {
  children: PropTypes.node.isRequired,
  loading: PropTypes.bool.isRequired,
  disabled: PropTypes.bool,
  fontStyles: PropTypes.string,
  styles: PropTypes.string,
  color: PropTypes.string,
  spinnerColor: PropTypes.string,
  dataId: PropTypes.string,
  onClick: PropTypes.func,
  spinnerWidth: PropTypes.number,
  requireClick: PropTypes.bool,
  type: PropTypes.string,
};

LoadingSpinnerButton.defaultProps = {
  color: 'red',
  dataId: '',
  disabled: false,
  fontStyles: '',
  onClick: () => {},
  requireClick: false,
  spinnerColor: 'white',
  spinnerWidth: 15,
  styles: '',
  type: 'button',
};

export default LoadingSpinnerButton;
