import React from 'react';
import { shallow } from 'enzyme';
import LoadingSpinnerButton from '../LoadingSpinnerButton';

describe('<LoadingSpinnerButton />', () => {
  let component;

  describe('when loading', () => {
    beforeEach(() => {
      component = shallow(
        <LoadingSpinnerButton loading>
          <div>super button</div>
        </LoadingSpinnerButton>,
      );
    });

    it('renders a loading spinner', () => {
      expect(component.find('MockSpinner')).toHaveLength(1);
    });

    it('is disabled', () => {
      expect(component.find('MockButton').props().disabled).toEqual(true);
    });
  });

  describe('when not loading', () => {
    beforeEach(() => {
      component = shallow(
        <LoadingSpinnerButton loading={false}>
          <div>super button</div>
        </LoadingSpinnerButton>,
      );
    });

    it('does not render a loading spinner', () => {
      expect(component.find('MockSpinner')).toHaveLength(0);
    });
  });

  describe('when a click is required', () => {
    describe('when loading', () => {
      beforeEach(() => {
        component = shallow(
          <LoadingSpinnerButton loading requireClick>
            <div>super button</div>
          </LoadingSpinnerButton>,
        );
      });

      it('does not render a spinner', () => {
        expect(component.find('MockSpinner')).toHaveLength(0);
      });

      describe('when the button is clicked', () => {
        beforeEach(() => {
          component.find('MockButton').simulate('click');
        });

        it('renders a spinner', () => {
          expect(component.find('MockSpinner')).toHaveLength(1);
        });

        describe('when loading stops', () => {
          beforeEach(() => {
            component.setProps({ loading: false });
          });

          it('stops spinning', () => {
            expect(component.find('MockSpinner')).toHaveLength(0);
          });

          it('does not spin again until clicked', () => {
            component.setProps({ loading: true });
            expect(component.find('MockSpinner')).toHaveLength(0);
          });
        });
      });
    });
  });
});
